﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.ComponentModel;
using SQLiteNetExtensions.Attributes;

namespace DansApp.Model
{
    //Tots els atributs coinicideixen amb el nom dels camps de la base de dades
    [SQLite.Net.Attributes.Table("Activitat")]
    public class Activitat : INotifyPropertyChanged
    {
        [SQLite.Net.Attributes.ColumnAttribute("id"), SQLite.Net.Attributes.NotNullAttribute, SQLite.Net.Attributes.PrimaryKeyAttribute, SQLite.Net.Attributes.AutoIncrement, SQLite.Net.Attributes.UniqueAttribute]
        public int Id { get; set; }
        [SQLite.Net.Attributes.ColumnAttribute("nom"), SQLite.Net.Attributes.NotNullAttribute]
        public string Nom
        {
            get { return this.nomValue; }

            set
            {
                if (value != this.nomValue)
                {
                    this.nomValue = value;
                    NotifyPropertyChanged("Nom");
                }
            }
        }

        [SQLite.Net.Attributes.ColumnAttribute("mes"), SQLite.Net.Attributes.NotNullAttribute]
        public string Mes
        {
            get { return this.mesValue; }

            set
            {
                if (value != this.mesValue)
                {
                    this.mesValue = value;
                    NotifyPropertyChanged("Mes");
                }
            }
        }
        [SQLite.Net.Attributes.ColumnAttribute("dia"), SQLite.Net.Attributes.NotNullAttribute]
        public string Dia
        {
            get { return this.diaValue; }

            set
            {
                if (value != this.diaValue)
                {
                    this.diaValue = value;
                    NotifyPropertyChanged("Dia");
                }
            }
        }
        [SQLite.Net.Attributes.ColumnAttribute("hora"), SQLite.Net.Attributes.NotNullAttribute]
        public string Hora
        {
            get { return this.horaValue; }

            set
            {
                if (value != this.horaValue)
                {
                    this.horaValue = value;
                    NotifyPropertyChanged("Hora");
                }
            }
        }
        [SQLite.Net.Attributes.ColumnAttribute("preu"), SQLite.Net.Attributes.NotNullAttribute]
        public decimal? Preu
        {
            get { return this.preuValue; }

            set
            {
                if (value != this.preuValue)
                {
                    this.preuValue = value;
                    NotifyPropertyChanged("Preu");
                }
            }
        }
        [SQLite.Net.Attributes.ColumnAttribute("preu_total")]
        public decimal? PreuTotal
        {
            get { return this.preuTotalValue; }

            set
            {
                if (value != this.preuTotalValue)
                {
                    this.preuTotalValue = value;
                    NotifyPropertyChanged("PreuTotal");
                }
            }
        }

        [ForeignKey(typeof(Nivell)), SQLite.Net.Attributes.ColumnAttribute("nivell")]     // S'especifica la clau forànea
        public int NivellId { get; set; }
        [ManyToOne("NivellId", "Activitats"), SQLite.Net.Attributes.NotNullAttribute]
        public Nivell Nivell
        {
            get { return this.nivellValue; }
            set
            {
                if (value != this.nivellValue)
                {
                    this.nivellValue = value;
                    NotifyPropertyChanged("Nivell");
                }
            }
        }

        [ForeignKey(typeof(FormaPagament)), SQLite.Net.Attributes.ColumnAttribute("formapagament")]     // S'especifica la clau forànea
        public int FormaPagamentId { get; set; }
        [ManyToOne("FormaPagamentId", "Activitats"), SQLite.Net.Attributes.NotNullAttribute]
        public FormaPagament FormaPagament
        {
            get { return this.formaPagamentValue; }
            set
            {
                if (value != this.formaPagamentValue)
                {
                    this.formaPagamentValue = value;
                    NotifyPropertyChanged("FormaPagament");
                }
            }
        }

        [ManyToMany(typeof(ActivitatAula))]
        public List<Aula> Aulas
        {
            get { return this.aulasValue; }
            set
            {
                if (value != this.aulasValue)
                {
                    this.aulasValue = value;
                    NotifyPropertyChanged("Aulas");
                }
            }
        }

        [ManyToMany(typeof(ActivitatProfessor))]
        public List<Professor> Professors
        {
            get { return this.professorsValue; }
            set
            {
                if (value != this.professorsValue)
                {
                    this.professorsValue = value;
                    NotifyPropertyChanged("Professors");
                }
            }
        }

        [ManyToMany(typeof(ActivitatAlumne))]
        public List<Alumne> Alumnes
        {
            get { return this.alumnesValue; }
            set
            {
                if (value != this.alumnesValue)
                {
                    this.alumnesValue = value;
                    NotifyPropertyChanged("Alumnes");
                }
            }
        }

        //Aquest atributs no es troben a la base de dades, són variables de la pròpia classe.
        [SQLite.Net.Attributes.Ignore]
        public bool CheckboxState
        {
            get { return chkStateValue; }
            set { chkStateValue = value; NotifyPropertyChanged("CheckboxState"); }
        }

        [SQLite.Net.Attributes.Ignore]
        public string HaveAulas
        {
            get { return string.IsNullOrEmpty(haveAulasValue) ? "Collapsed" : haveAulasValue; }
            set { haveAulasValue = value; NotifyPropertyChanged("HaveAulas"); }
        }

        [SQLite.Net.Attributes.Ignore]
        public string HourAndActivityName
        {
            get { return this.Hora + " " + this.Nom; }
        }

        [SQLite.Net.Attributes.Ignore]
        public bool HaPagat
        {
            get { return haPagatValue; }
            set { haPagatValue = value; NotifyPropertyChanged("HaPagat"); }
        }

        [SQLite.Net.Attributes.Ignore]
        public string NomPreu
        {
            get { return nomValue + " Preu: " + preuValue + " - "; }
        }

        [SQLite.Net.Attributes.Ignore]
        public string ActivitatDiaHora
        {
            get { return nomValue + ": " + diaValue + " " + horaValue; }
        }

        /* Variables privades */
        private int idValue;
        private int idNivellValue;
        private int idFormaPagamentValue;
        private string nomValue = string.Empty;
        private string mesValue = string.Empty;
        private string diaValue = string.Empty;
        private string horaValue = string.Empty;
        private decimal? preuValue;
        private decimal? preuTotalValue;
        private Nivell nivellValue;
        private FormaPagament formaPagamentValue;
        private List<Aula> aulasValue;
        private List<Professor> professorsValue;
        private List<Alumne> alumnesValue;
        private bool chkStateValue;
        private string haveAulasValue;
        private bool haPagatValue;

        public Activitat()
        {
            //Constructor de classe vuit. 
        }

        //Construtor amb paràmetres.
        public Activitat(string nom, Nivell nivell, long? preu, FormaPagament formapagament, string mes, string dia, string hora, bool chk = false, string haveAulas = "Collapsed")
        {
            Nom = nom;
            NivellId = nivell.Id;
            Nivell = nivell;
            Preu = preu;
            FormaPagamentId = formapagament.Id;
            FormaPagament = formapagament;
            Mes = mes;
            Dia = dia;
            Hora = hora;
            CheckboxState = chk;
            HaveAulas = haveAulas;
        }

        public event PropertyChangedEventHandler PropertyChanged;
        //Notifica que el valor ha canviat.
        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
    }


    //Classe entitat - relació que hi ha entre una activitat y un alumne
    [SQLite.Net.Attributes.Table("ActivitatAlumne")]
    public class ActivitatAlumne
    {
        [SQLite.Net.Attributes.ColumnAttribute("id"), SQLite.Net.Attributes.NotNullAttribute, SQLite.Net.Attributes.PrimaryKeyAttribute, SQLite.Net.Attributes.AutoIncrement, SQLite.Net.Attributes.UniqueAttribute]
        public int Id { get; set; }

        [ForeignKey(typeof(Activitat)), SQLite.Net.Attributes.ColumnAttribute("id_activitat")]
        public int Id_Activitat { get; set; }
        [ForeignKey(typeof(Alumne)), SQLite.Net.Attributes.ColumnAttribute("id_alumne")]
        public int Id_Alumne { get; set; }
        [SQLite.Net.Attributes.ColumnAttribute("pagat")]
        public int Pagat { get; set; }
        [SQLite.Net.Attributes.ColumnAttribute("data_pagament")]
        public string DataPagament { get; set; }     
    }

    //Classe entitat - relació que hi ha entre una activitat y una aula
    [SQLite.Net.Attributes.Table("ActivitatAula")]
    public class ActivitatAula
    {
        [SQLite.Net.Attributes.ColumnAttribute("id"), SQLite.Net.Attributes.NotNullAttribute, SQLite.Net.Attributes.PrimaryKeyAttribute, SQLite.Net.Attributes.AutoIncrement, SQLite.Net.Attributes.UniqueAttribute]
        public int Id { get; set; }

        [ForeignKey(typeof(Activitat)), SQLite.Net.Attributes.ColumnAttribute("id_activitat")]
        public int Id_Activitat { get; set; }
        [ForeignKey(typeof(Aula)), SQLite.Net.Attributes.ColumnAttribute("id_aula")]
        public int Id_Aula { get; set; }
    }

    //Classe entitat - relació que hi ha entre una activitat y un professor
    [SQLite.Net.Attributes.Table("ActivitatProfessor")]
    public class ActivitatProfessor
    {
        [SQLite.Net.Attributes.ColumnAttribute("id"), SQLite.Net.Attributes.NotNullAttribute, SQLite.Net.Attributes.PrimaryKeyAttribute, SQLite.Net.Attributes.AutoIncrement, SQLite.Net.Attributes.UniqueAttribute]
        public int Id { get; set; }

        [ForeignKey(typeof(Activitat)), SQLite.Net.Attributes.ColumnAttribute("id_activitat")]
        public int Id_Activitat { get; set; }
        [ForeignKey(typeof(Professor)), SQLite.Net.Attributes.ColumnAttribute("id_professor")]
        public int Id_Professor { get; set; }
        [SQLite.Net.Attributes.ColumnAttribute("cost")]
        public int Cost { get; set; }
        [SQLite.Net.Attributes.ColumnAttribute("pagat")]
        public int Pagat { get; set; }
    }

}