﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using SQLiteNetExtensions.Attributes;

namespace DansApp.Model
{
    //Tots els atributs coinicideixen amb el nom dels camps de la base de dades
    [SQLite.Net.Attributes.Table("Alumne")]
    public class Alumne : INotifyPropertyChanged
    {
        /* Public variables */
        [SQLite.Net.Attributes.ColumnAttribute("id"), SQLite.Net.Attributes.NotNullAttribute, SQLite.Net.Attributes.PrimaryKeyAttribute, SQLite.Net.Attributes.AutoIncrement, SQLite.Net.Attributes.UniqueAttribute]
        public int Id { get; set; }
        [SQLite.Net.Attributes.ColumnAttribute("nom"), SQLite.Net.Attributes.NotNullAttribute]
        public string Nom
        {
            get { return this.nomValue; }

            set
            {
                if (value != this.nomValue)
                {
                    this.nomValue = value;
                    NotifyPropertyChanged("Nom");
                }
            }
        }
        [SQLite.Net.Attributes.ColumnAttribute("cognoms")]
        public string Cognoms
        {
            get { return this.cognoms; }

            set
            {
                if (value != this.cognoms)
                {
                    this.cognoms = value;
                    NotifyPropertyChanged("Cognoms");
                }
            }
        }
        [SQLite.Net.Attributes.ColumnAttribute("email")]
        public string Email
        {
            get { return this.emailValue; }

            set
            {
                if (value != this.emailValue)
                {
                    this.emailValue = value;
                    NotifyPropertyChanged("Email");
                }
            }
        }

        [SQLite.Net.Attributes.ColumnAttribute("telefon")]
        public long? Telefon
        {
            get { return this.telefonValue; }

            set
            {
                if (value != this.telefonValue)
                {
                    this.telefonValue = value;
                    NotifyPropertyChanged("Telefon");
                }
            }
        }

        [ManyToMany(typeof(ActivitatAlumne))]
        public List<Activitat> Activitats
        {
            get { return this.activitatsValue; }
            set
            {
                if (value != this.activitatsValue)
                {
                    this.activitatsValue = value;
                    NotifyPropertyChanged("Activitats");
                }
            }
        }

        //Aquest atributs no es troben a la base de dades, són variables de la pròpia classe.
        [SQLite.Net.Attributes.Ignore]
        public bool CheckboxState
        {
            get { return chkStateValue; }
            set { chkStateValue = value; NotifyPropertyChanged("CheckboxState"); }
        }

        [SQLite.Net.Attributes.Ignore]
        public string HaveActivitats
        {
            get { return string.IsNullOrEmpty(haveActivitatsValue) ? "Collapsed" : haveActivitatsValue; }
            set { haveActivitatsValue = value; NotifyPropertyChanged("HaveActivitats"); }
        }

        [SQLite.Net.Attributes.Ignore]
        public bool HaPagat
        {
            get { return haPagatValue; }
            set { haPagatValue = value; NotifyPropertyChanged("HaPagat"); }
        }

        [SQLite.Net.Attributes.Ignore]
        public string NomAlumne
        {
            get { return this.nomValue + " - "; }
        }

        [SQLite.Net.Attributes.Ignore]
        public string NomCognoms
        {
            get { return nomValue + " " + cognoms; }
        }

        /* Variables privades */
        private int idValue;
        private string nomValue = String.Empty;
        private string cognoms = String.Empty;
        private string emailValue = String.Empty;
        private long? telefonValue;
        private List<Activitat> activitatsValue;
        private bool chkStateValue;
        private string haveActivitatsValue;
        private bool haPagatValue;


        public Alumne()
        {
            //Constructor de classe vuit. 
        }
        //Construtor amb paràmetres.
        public Alumne(string nom, string cognoms, string email, long? telefon, List<Activitat> activitats, bool chk = false, string haveActivitats = "Collapsed")
        {
            Nom = nom;
            Cognoms = cognoms;
            Email = email;
            Telefon = telefon;
            Activitats = activitats;

            CheckboxState = chk;
            HaveActivitats = haveActivitats;
        }

        public event PropertyChangedEventHandler PropertyChanged;
        //Notifica que el valor ha canviat.
        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
    }
}
