﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using SQLiteNetExtensions.Attributes;

namespace DansApp.Model
{
    //Tots els atributs coinicideixen amb el nom dels camps de la base de dades
    [SQLite.Net.Attributes.Table("Aula")]
    public class Aula : INotifyPropertyChanged
    {
        [SQLite.Net.Attributes.ColumnAttribute("id"), SQLite.Net.Attributes.NotNullAttribute, SQLite.Net.Attributes.PrimaryKeyAttribute, SQLite.Net.Attributes.AutoIncrement, SQLite.Net.Attributes.UniqueAttribute]
        public int Id { get; set; }
        [SQLite.Net.Attributes.ColumnAttribute("nom"), SQLite.Net.Attributes.NotNullAttribute, SQLite.Net.Attributes.UniqueAttribute]
        public string Nom
        {
            get { return this.nomValue; }

            set
            {
                if (value != this.nomValue)
                {
                    this.nomValue = value;
                    NotifyPropertyChanged("Nom");
                }
            }
        }
        [SQLite.Net.Attributes.ColumnAttribute("direccio")]
        public string Direccio
        {
            get { return this.direccioValue; }

            set
            {
                if (value != this.direccioValue)
                {
                    this.direccioValue = value;
                    NotifyPropertyChanged("Direccio");
                }
            }
        }
        [SQLite.Net.Attributes.ColumnAttribute("poblacio")]
        public string Poblacio
        {
            get { return this.poblacioValue; }

            set
            {
                if (value != this.poblacioValue)
                {
                    this.poblacioValue = value;
                    NotifyPropertyChanged("Poblacio");
                }
            }
        }

        [ManyToMany(typeof(ActivitatAula))]
        public List<Activitat> Activitats
        {
            get { return this.activitatsValue; }
            set
            {
                if (value != this.activitatsValue)
                {
                    this.activitatsValue = value;
                    NotifyPropertyChanged("Activitats");
                }
            }
        }
        //Aquest atributs no es troben a la base de dades, són variables de la pròpia classe.
        [SQLite.Net.Attributes.Ignore]
        public bool CheckboxState
        {
            get { return chkStateValue; }
            set { chkStateValue = value; NotifyPropertyChanged("CheckboxState"); }
        }

        [SQLite.Net.Attributes.Ignore]
        public string HaveActivitats
        {
            get { return string.IsNullOrEmpty(haveActivitatsValue) ? "Collapsed" : haveActivitatsValue; }
            set { haveActivitatsValue = value; NotifyPropertyChanged("HaveActivitats"); }
        }

        /* Variables privades */
        private int idValue;
        private string nomValue = String.Empty;
        private string direccioValue = String.Empty;
        private string poblacioValue = String.Empty;
        private List<Activitat> activitatsValue;
        private bool chkStateValue;
        private string haveActivitatsValue;

        public Aula()
        {
            //Constructor de classe vuit. 
        }
        //Construtor amb paràmetres.
        public Aula(string nom)
        {
            Nom = nom;
        }
        //Construtor amb paràmetres.
        public Aula(string nom, string direccio, string poblacio, bool chk = false, string haveActivitats = "Collapsed")
        {
            Nom = nom;
            Direccio = direccio;
            Poblacio = poblacio;

            CheckboxState = chk;
            HaveActivitats = haveActivitats;
        }

        public event PropertyChangedEventHandler PropertyChanged;
        //Notifica que el valor ha canviat.
        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
    }
}
