﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using DansApp.Model;
using SQLiteNetExtensions.Attributes;
using SQLiteNetExtensions.Extensions.TextBlob;
using SQLiteNetExtensions.Exceptions;
using SQLite.Net.Attributes;
using SQLite.Net;

namespace DansApp.ViewModel
{

    //Aquesta classe conté totes les operacions CRUID
    public class DatabaseHelperClass
    {
        SQLiteConnection dbConn;

        private static object objectNavigationData = null;
        public static object ObjectNavigationData
        {
            get { return objectNavigationData; }
            set { objectNavigationData = value; }


        }


        public async Task<bool> OnCreate(string DB_PATH)
        {
            try
            {
                if (!CheckFileExists(DB_PATH).Result)
                {
                    using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), DB_PATH))
                    {
                        dbConn.CreateTable<Aula>();
                    }
                }
                return true;
            }
            catch
            {
                return false;
            }
        }

        private async Task<bool> CheckFileExists(string fileName)
        {
            try
            {
                var store = await Windows.Storage.ApplicationData.Current.LocalFolder.GetFileAsync(fileName);
                return true;
            }
            catch
            {
                return false;
            }
        }


        #region Aula 
        // Recupera la informació d'una aula específica la base de dades.
        public Aula ReadAula(int aulaid)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingaula = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Aula>(dbConn, aulaid);//dbConn.Query<Aula>("select * from Aula where Id =" + aulaid).FirstOrDefault();
                return existingaula;
            }
        }
        // Recupera tota la llista d'aules de la base de dades.
        public ObservableCollection<Aula> ReadAulas()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<Aula> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<Aula>(dbConn);// = dbConn.Table<Alumne>().ToList<Alumne>();// = dbConn.Table<Aula>().ToList<Aula>();
                ObservableCollection<Aula> AulasList = new ObservableCollection<Aula>(myCollection);
                return AulasList;
            }
        }

        //Actualitza la información d'una aula
        public void UpdateAula(Aula aula)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingaula = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Aula>(dbConn, aula.Id); //dbConn.Query<Aula>("select * from Aula where Id =" + aula.Id).FirstOrDefault();
                if (existingaula != null)
                {
                    existingaula.Nom = aula.Nom;
                    existingaula.Direccio = aula.Direccio;
                    existingaula.Poblacio = aula.Poblacio;

                    dbConn.RunInTransaction(() =>
                    {
                        dbConn.Update(existingaula);
                    });
                }
            }
        }
        //Consulta si existeix una aula
        public bool ExistsAulaNom(Aula newaula)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingaula = dbConn.Query<Aula>("select * from Aula where Nom ='" + newaula.Nom + "'").FirstOrDefault();
                if (existingaula != null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        // Inserta una nova aula a la base de dades
        public void Insert(Aula newaula)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {

                dbConn.RunInTransaction(() =>
                {
                    dbConn.Insert(newaula);
                });
            }
        }

        //Esborra una aula de la base de dades
        public void DeleteAula(int Id)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingaula = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Aula>(dbConn, Id);
                if (existingaula != null)
                {
                    dbConn.RunInTransaction(() =>
                    {
                        SQLiteNetExtensions.Extensions.WriteOperations.Delete(dbConn, existingaula, false);
                    });
                }
            }
        }
        //Esborra totes les aules de la base de dades
        public void DeleteAllAula()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                //dbConn.RunInTransaction(() =>
                //   {
                dbConn.DropTable<Aula>();
                dbConn.CreateTable<Aula>();
                dbConn.Dispose();
                dbConn.Close();
                //});
            }
        }
        #endregion

        #region Professor
        // Recupera la informació d'un porfessor específic la base de dades.
        public Professor ReadProfessor(int professorid)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingprofessor = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Professor>(dbConn, professorid);//dbConn.Query<Professor>("select * from Professor where Id =" + professorid).FirstOrDefault();

                return existingprofessor;
            }
        }
        // Recupera tota la llista de professors de la base de dades.
        public ObservableCollection<Professor> ReadProfessors()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<Professor> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<Professor>(dbConn);// = dbConn.Table<Alumne>().ToList<Alumne>();
                ObservableCollection<Professor> ProfessorsList = new ObservableCollection<Professor>(myCollection);
                return ProfessorsList;
            }
        }

        //Actualitza la informació d'un professor
        public void UpdateProfessor(Professor professor)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingprofessor = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Professor>(dbConn, professor.Id); //dbConn.Query<Professor>("select * from Professor where Id =" + professor.Id).FirstOrDefault();
                if (existingprofessor != null)
                {
                    existingprofessor.Nom = professor.Nom;
                    existingprofessor.Cognoms = professor.Cognoms;
                    existingprofessor.Email = professor.Email;
                    existingprofessor.Telefon = professor.Telefon;
                    existingprofessor.Activitats = professor.Activitats;

                    dbConn.RunInTransaction(() =>
                    {
                        SQLiteNetExtensions.Extensions.WriteOperations.UpdateWithChildren(dbConn, existingprofessor);
                    });
                }
            }
        }

        // Insereix un nou professor a la base de dades.
        public void Insert(Professor newprofessor)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                dbConn.RunInTransaction(() =>
                {
                    SQLiteNetExtensions.Extensions.WriteOperations.InsertWithChildren(dbConn, newprofessor);
                    //dbConn.Insert(newprofessor);
                });
            }
        }

        //Esborra la informació d'un professor de la base de dades.
        public void DeleteProfessor(int Id)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingprofessor = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Professor>(dbConn, Id);
                if (existingprofessor != null)
                {
                    dbConn.RunInTransaction(() =>
                    {
                        SQLiteNetExtensions.Extensions.WriteOperations.Delete(dbConn, existingprofessor, false);
                    });
                }
            }
        }
        //Esborra tota la taula de professors.
        public void DeleteAllProfessor()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                //dbConn.RunInTransaction(() =>
                //   {
                dbConn.DropTable<Professor>();
                dbConn.CreateTable<Professor>();
                dbConn.Dispose();
                dbConn.Close();
                //});
            }
        }
        #endregion

        #region Alumne
        // Recupera la informació d'un alumne específic la base de dades.
        public Alumne ReadAlumne(int alumneid)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingalumne = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Alumne>(dbConn, alumneid);
                return existingalumne;
            }
        }
        // Recupera tota la llista d'alumnes de la base de dades.
        public ObservableCollection<Alumne> ReadAlumnes()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<Alumne> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<Alumne>(dbConn);// = dbConn.Table<Alumne>().ToList<Alumne>();
                ObservableCollection<Alumne> AlumnesList = new ObservableCollection<Alumne>(myCollection);
                return AlumnesList;
            }
        }

        //Actualitza la informació d'un alumne
        public void UpdateAlumne(Alumne alumne)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingalumne = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Alumne>(dbConn, alumne.Id);
                if (existingalumne != null)
                {
                    existingalumne.Nom = alumne.Nom;
                    existingalumne.Cognoms = alumne.Cognoms;
                    existingalumne.Email = alumne.Email;
                    existingalumne.Telefon = alumne.Telefon;
                    existingalumne.Activitats = alumne.Activitats;

                    dbConn.RunInTransaction(() =>
                    {
                        SQLiteNetExtensions.Extensions.WriteOperations.UpdateWithChildren(dbConn, existingalumne);
                        //dbConn.Update(existingalumne);
                    });
                }
            }
        }

        // Insereix un nou alumne a la base de dades.
        public void Insert(Alumne newalumne)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                dbConn.RunInTransaction(() =>
                {
                    //dbConn.Insert(newalumne);
                    SQLiteNetExtensions.Extensions.WriteOperations.InsertWithChildren(dbConn, newalumne);
                });
            }
        }

        //Esborra la informació d'un alumne de la base de dades.
        public void DeleteAlumne(int Id)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingalumne = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Alumne>(dbConn, Id); //dbConn.Query<Professor>("select * from Professor where Id =" + Id).FirstOrDefault();

                if (existingalumne != null)
                {
                    dbConn.RunInTransaction(() =>
                    {
                        SQLiteNetExtensions.Extensions.WriteOperations.Delete(dbConn, existingalumne, false);
                    });
                }
            }
        }
        //Esborra tota la taula de alumnes.
        public void DeleteAllAlumne()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                //dbConn.RunInTransaction(() =>
                //   {
                dbConn.DropTable<Alumne>();
                dbConn.CreateTable<Alumne>();
                dbConn.Dispose();
                dbConn.Close();
                //});
            }
        }
        #endregion

        #region Activitat
        // Recupera la informació d'una activitat específica la base de dades.
        public Activitat ReadActivitat(int activitatid)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingactivitat = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Activitat>(dbConn, activitatid);
                return existingactivitat;
            }
        }
        // Recupera el llistat de totes les activitatas de la base de dades.
        public ObservableCollection<Activitat> ReadActivitats()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<Activitat> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<Activitat>(dbConn);
                ObservableCollection<Activitat> ActivitatsList = new ObservableCollection<Activitat>(myCollection);
                return ActivitatsList;
            }
        }

        // Recupera les 5 activitats que més alumnes té
        public ObservableCollection<Activitat> ReadTop5Activitats()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<Activitat> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<Activitat>(dbConn);

                var list = (from t in myCollection
                            where t.Alumnes.Count > 0
                            orderby t.Alumnes.Count descending
                            select t).Take(5);

                ObservableCollection<Activitat> ActivitatsList = new ObservableCollection<Activitat>(list);
                return ActivitatsList;
            }
        }
        // Recupera el nivell més utilitzat
        public Nivell ReadTopNivell()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<Nivell> nivells = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<Nivell>(dbConn);

                var list = (from t in nivells
                            where t.Activitats.Count > 0
                            orderby t.Activitats.Count descending
                            select t).Take(1);

                Nivell niv = list.FirstOrDefault();
                return niv;
            }
        }
        //Consulta si un alumne ha pagat la seva activitat
        public bool ReadHaPagat(int alumneid, int activitatid)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingactivitatalumne = dbConn.Query<ActivitatAlumne>("select * from ActivitatAlumne where id_activitat=" + activitatid + " and id_alumne=" + alumneid).FirstOrDefault();

                if (existingactivitatalumne != null)
                {
                    if (existingactivitatalumne.Pagat > 0)
                    {
                        return true;
                    }
                    else
                    {
                        return false;
                    }
                }
                else
                {
                    return false;
                }
            }
        }

        //Actualitza el pagament d'un alumne per una activitat
        public void UpdateHaPagat(int alumneid, int activitatid)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingactivitatalumne = dbConn.Query<ActivitatAlumne>("select * from ActivitatAlumne where id_activitat=" + activitatid + " and id_alumne=" + alumneid).FirstOrDefault();

                if (existingactivitatalumne != null)
                {
                    if (existingactivitatalumne.Pagat > 0)
                    {
                        existingactivitatalumne.Pagat = 0;
                        existingactivitatalumne.DataPagament = "";
                    }
                    else
                    {
                        existingactivitatalumne.Pagat = 1;
                        existingactivitatalumne.DataPagament = DateTime.Now.ToString("yyyy-MM-dd HH':'mm':'ss");
                    }

                    dbConn.RunInTransaction(() =>
                    {
                        dbConn.Update(existingactivitatalumne);
                    });
                }
            }
        }

        //Actualitza la informació d'una activitat
        public void UpdateActivitat(Activitat activitat)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingactivitat = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Activitat>(dbConn, activitat.Id);
                if (existingactivitat != null)
                {
                    existingactivitat.Nom = activitat.Nom;
                    existingactivitat.NivellId = activitat.NivellId;
                    existingactivitat.Nivell = activitat.Nivell;
                    existingactivitat.FormaPagamentId = activitat.FormaPagamentId;
                    existingactivitat.FormaPagament = activitat.FormaPagament;
                    existingactivitat.Mes = activitat.Mes;
                    existingactivitat.Dia = activitat.Dia;
                    existingactivitat.Hora = activitat.Hora;
                    existingactivitat.Preu = activitat.Preu;

                    existingactivitat.Aulas = activitat.Aulas;
                    existingactivitat.Professors = activitat.Professors;
                    existingactivitat.Alumnes = activitat.Alumnes;

                    dbConn.RunInTransaction(() =>
                    {
                        SQLiteNetExtensions.Extensions.WriteOperations.UpdateWithChildren(dbConn, existingactivitat);
                    });
                }
            }
        }

        //Reseteja els pagaments dels alumnes
        public void ResetActivitatAlumnePagament()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<ActivitatAlumne> actAlumneList = dbConn.Query<ActivitatAlumne>("select * from ActivitatAlumne");

                foreach (var activitatAlumne in actAlumneList)
                {
                    activitatAlumne.DataPagament = "";
                }

                dbConn.RunInTransaction(() =>
                {
                    dbConn.UpdateAll(actAlumneList);
                });
            }
        }

        //Reseteja els pagamaents dels alumnes depenent de la seva forma de pagament.
        public void ResetActivitatAlumnePagamentByFormaPagament()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<ActivitatAlumne> actAlumneList = dbConn.Query<ActivitatAlumne>("select * from ActivitatAlumne");

                foreach (var activitatAlumne in actAlumneList)
                {
                    var activitat = dbConn.Query<Activitat>("select * from Activitat where id=" + activitatAlumne.Id_Activitat).FirstOrDefault();

                    if (activitat != null)
                    {
                        switch (activitat.FormaPagamentId)
                        {
                            case 1:
                                //Mensual
                                activitatAlumne.Pagat = 0;
                                activitatAlumne.DataPagament = "";
                                break;
                            case 2:
                                //BiMensual
                                if (DateTime.Today.Month == 1 || DateTime.Today.Month == 3 || DateTime.Today.Month == 5
                                 || DateTime.Today.Month == 7 || DateTime.Today.Month == 9 || DateTime.Today.Month == 11)
                                {
                                    activitatAlumne.Pagat = 0;
                                    activitatAlumne.DataPagament = "";
                                }
                                break;
                            case 3:
                                //Trimestral
                                if (DateTime.Today.Month == 1 || DateTime.Today.Month == 4 || DateTime.Today.Month == 7 || DateTime.Today.Month == 10)
                                {
                                    activitatAlumne.Pagat = 0;
                                    activitatAlumne.DataPagament = "";
                                }
                                break;
                            case 4:
                                //Semestral
                                if (DateTime.Today.Month == 1 || DateTime.Today.Month == 7)
                                {
                                    activitatAlumne.Pagat = 0;
                                    activitatAlumne.DataPagament = "";
                                }
                                break;
                            case 5:
                                //Anual
                                if (DateTime.Today.Month == 1)
                                {
                                    activitatAlumne.Pagat = 0;
                                    activitatAlumne.DataPagament = "";
                                }
                                break;
                            default:
                                break;
                        }
                    }
                }

                dbConn.RunInTransaction(() =>
                {
                    dbConn.UpdateAll(actAlumneList);
                });
            }
        }

        //Insereix una nova activitat a la base de dades.
        public void Insert(Activitat newactivitat)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                dbConn.RunInTransaction(() =>
                {
                    SQLiteNetExtensions.Extensions.WriteOperations.InsertWithChildren(dbConn, newactivitat);
                });
            }
        }

        //Esborra una activitat de la base de dades.
        public void DeleteActivitat(int Id)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingactivitat = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Activitat>(dbConn, Id);

                if (existingactivitat != null)
                {
                    dbConn.RunInTransaction(() =>
                    {
                        SQLiteNetExtensions.Extensions.WriteOperations.Delete(dbConn, existingactivitat, false);
                    });
                }
            }
        }
        //Esborra totes les activitats de la taula.
        public void DeleteAllActivitat()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                //dbConn.RunInTransaction(() =>
                //   {
                dbConn.DropTable<Activitat>();
                dbConn.CreateTable<Activitat>();
                dbConn.Dispose();
                dbConn.Close();
                //});
            }
        }
        #endregion

        #region Nivell
        // Recupera la información d'un nivell.
        public Nivell ReadNivell(int nivellid)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingnivell = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<Nivell>(dbConn, nivellid);
                //var existingnivell = dbConn.Query<Nivell>("select * from Nivell where Id =" + nivellid).FirstOrDefault();

                return existingnivell;
            }
        }
        // Recupera tot el llista de nivells de la base de dades.
        public ObservableCollection<Nivell> ReadNivells()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<Nivell> myCollection = dbConn.Table<Nivell>().ToList<Nivell>();
                //List<Nivell> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<Nivell>(dbConn);

                ObservableCollection<Nivell> NivellsList = new ObservableCollection<Nivell>(myCollection);
                return NivellsList;
            }
        }

        // Recupera tots els nivells de les activitats
        public ObservableCollection<Nivell> ReadNivellsActivitats()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                //List<Nivell> myCollection = dbConn.Table<Nivell>().ToList<Nivell>();
                List<Nivell> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<Nivell>(dbConn);

                ObservableCollection<Nivell> NivellsList = new ObservableCollection<Nivell>(myCollection);
                return NivellsList;
            }
        }
        #endregion

        #region FormaPagament
        // Recupera la informació d'una forma de pagament específica
        public FormaPagament ReadFormaPagament(int formapagamentid)
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                var existingformapagament = SQLiteNetExtensions.Extensions.ReadOperations.GetWithChildren<FormaPagament>(dbConn, formapagamentid);
                //var existingformapagament = dbConn.Query<FormaPagament>("select * from FormaPagament where Id =" + formapagamentid).FirstOrDefault();

                return existingformapagament;
            }
        }
        // Recupera tot el llista de forma de pagaments de la base de dades.
        public ObservableCollection<FormaPagament> ReadFormaPagaments()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                List<FormaPagament> myCollection = dbConn.Table<FormaPagament>().ToList<FormaPagament>();
                //List<FormaPagament> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<FormaPagament>(dbConn);

                ObservableCollection<FormaPagament> FormaPagamentsList = new ObservableCollection<FormaPagament>(myCollection);
                return FormaPagamentsList;
            }
        }

        // Recupera les formes de pagament de totes les activitats
        public ObservableCollection<FormaPagament> ReadFormaPagamentsActivitats()
        {
            using (dbConn = new SQLiteConnection(new SQLite.Net.Platform.WindowsPhone8.SQLitePlatformWP8(), App.DB_PATH))
            {
                //List<FormaPagament> myCollection = dbConn.Table<Nivell>().ToList<Nivell>();
                List<FormaPagament> myCollection = SQLiteNetExtensions.Extensions.ReadOperations.GetAllWithChildren<FormaPagament>(dbConn);

                ObservableCollection<FormaPagament> FormaPagamentsList = new ObservableCollection<FormaPagament>(myCollection);
                return FormaPagamentsList;
            }
        }
        #endregion
    }
}
