﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using DansApp.ViewModel;
using DansApp.Model;
using System.Text.RegularExpressions;

namespace DansApp.Views.Alumne
{
    public partial class AddAlumne : PhoneApplicationPage
    {
        Model.Alumne newalumne = new Model.Alumne();

        public AddAlumne()
        {
            InitializeComponent();
            this.Loaded += ReadActivitatsList_Loaded;
        }

        private bool IsValidEmail(string emailAddress)
        {
            return Regex.IsMatch(emailAddress, @"^([0-9a-zA-Z]([-\.\w]*[0-9a-zA-Z])*@([0-9a-zA-Z][-\w]*[0-9a-zA-Z]\.)+[a-zA-Z]{2,9})$");
        }


        private void ReadActivitatsList_Loaded(object sender, RoutedEventArgs e)
        {
            if (newalumne.Activitats == null)
            {
                newalumne.Activitats = new List<Model.Activitat>();
            }
            if (NavigationContext.QueryString.ContainsKey("alumne"))
            {
                string parameter = NavigationContext.QueryString["alumne"];

                switch (parameter)
                {
                    case "1":
                        var myParameter = NavigationService.GetLastNavigationData();
                        if (myParameter != null)
                        {
                            newalumne = (Model.Alumne)myParameter;
                            if (newalumne != null)
                            {
                                txtNom.Text = newalumne.Nom;
                                txtCognoms.Text = newalumne.Cognoms;
                                txtEmail.Text = newalumne.Email;
                                txtTelefon.Text = newalumne.Telefon.ToString();
                                if (newalumne.Activitats != null)
                                {
                                    lbActivitats.ItemsSource = newalumne.Activitats.OrderBy(i => i.Nom).ToList();
                                }
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }

        private void btnAddAlumne_Click(object sender, RoutedEventArgs e)
        {
            long telefon;
            DatabaseHelperClass Db_Helper = new DatabaseHelperClass();
            if (string.IsNullOrEmpty(txtNom.Text))
            {
                MessageBox.Show("El nom és obligatori!");
            }
            else if (!string.IsNullOrEmpty(txtEmail.Text) && !this.IsValidEmail(txtEmail.Text))
            {
                MessageBox.Show("Siusplau introdueix un email amb format vàlid!");
            }
            else if (!string.IsNullOrEmpty(txtTelefon.Text) && !(long.TryParse(txtTelefon.Text, out telefon)))
            {
                MessageBox.Show("El telèfon no pot contenir caracters!");
            }
            else
            {
                long tempVal;
                long? tlf = Int64.TryParse(txtTelefon.Text, out tempVal) ? tempVal : (long?)null;
                newalumne.Nom = txtNom.Text;
                newalumne.Cognoms = txtCognoms.Text;
                newalumne.Email = txtEmail.Text;
                newalumne.Telefon = tlf;

                Db_Helper.Insert(newalumne);
                NavigationService.Navigate(new Uri("/Views/Alumne/ReadAlumneList.xaml", UriKind.Relative));
            }
        }
        private void btnMenu_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/MainPage.xaml", UriKind.Relative));
        }

        private void btnSelActivitats_Click(object sender, RoutedEventArgs e)
        {
            long tempVal;
            long? tlf = Int64.TryParse(txtTelefon.Text, out tempVal) ? tempVal : (long?)null;
            newalumne.Nom = txtNom.Text;
            newalumne.Cognoms = txtCognoms.Text;
            newalumne.Email = txtEmail.Text;
            newalumne.Telefon = tlf;

            NavigationService.Navigate(new Uri("/Views/Alumne/SelectActivitatAlumne.xaml?alumne=1", UriKind.Relative).ToString(), newalumne);
        }
    }
}