﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using DansApp.ViewModel;
using DansApp.Model;
using System.Text.RegularExpressions;


namespace DansApp.Views.Alumne
{
    public partial class UpdateDeleteAlumne : PhoneApplicationPage
    {
        int Selected_AlumneId = 0;

        DatabaseHelperClass Db_Helper = new DatabaseHelperClass();
        Model.Alumne currentAlumne = new Model.Alumne();

        public UpdateDeleteAlumne()
        {
            InitializeComponent();
        }

        private bool IsValidEmail(string emailAddress)
        {
            return Regex.IsMatch(emailAddress, @"^([0-9a-zA-Z]([-\.\w]*[0-9a-zA-Z])*@([0-9a-zA-Z][-\w]*[0-9a-zA-Z]\.)+[a-zA-Z]{2,9})$");
        }


        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            if (NavigationContext.QueryString.ContainsKey("SelectedAlumneID"))
            {
                Selected_AlumneId = int.Parse(NavigationContext.QueryString["SelectedAlumneID"]);
                currentAlumne = Db_Helper.ReadAlumne(Selected_AlumneId);

                txtNom.Text = currentAlumne.Nom;
                txtCognoms.Text = currentAlumne.Cognoms;
                txtEmail.Text = currentAlumne.Email;
                txtTelefon.Text = currentAlumne.Telefon.ToString();
                lbActivitats.ItemsSource = currentAlumne.Activitats.OrderBy(i => i.Nom).ToList();
            }
            else
            {
                if (NavigationContext.QueryString.ContainsKey("alumne"))
                {
                    string parameter = NavigationContext.QueryString["alumne"];

                    switch (parameter)
                    {
                        case "1":
                            var myParameter = NavigationService.GetLastNavigationData();
                            if (myParameter != null)
                            {
                                currentAlumne = (Model.Alumne)myParameter;

                                if (currentAlumne != null)
                                {
                                    txtNom.Text = currentAlumne.Nom;
                                    txtCognoms.Text = currentAlumne.Cognoms;
                                    txtEmail.Text = currentAlumne.Email;
                                    txtTelefon.Text = currentAlumne.Telefon.ToString();

                                    if (currentAlumne.Activitats != null)
                                    {
                                        lbActivitats.ItemsSource = currentAlumne.Activitats.OrderBy(i => i.Nom).ToList();
                                    }
                                }
                            }
                            break;
                        default:
                            break;
                    }
                }
            }
        }


        private void btnUpdateAlumne_Click(object sender, RoutedEventArgs e)
        {
            long telefon;

            if (string.IsNullOrEmpty(txtNom.Text))
            {
                MessageBox.Show("El nom és obligatori!");
            }
            else if (!string.IsNullOrEmpty(txtEmail.Text) && !this.IsValidEmail(txtEmail.Text))
            {
                MessageBox.Show("Siusplau introdueix un email amb format vàlid!");
            }
            else if (!string.IsNullOrEmpty(txtTelefon.Text) && !(long.TryParse(txtTelefon.Text, out telefon)))
            {
                MessageBox.Show("El telèfon no pot contenir caracters!");
            }
            else
            {
                currentAlumne.Nom = txtNom.Text;
                currentAlumne.Cognoms = txtCognoms.Text;
                currentAlumne.Email = txtEmail.Text;
                long tempVal;
                long? tlf = Int64.TryParse(txtTelefon.Text, out tempVal) ? tempVal : (long?)null;
                currentAlumne.Telefon = tlf;

                Db_Helper.UpdateAlumne(currentAlumne);
                NavigationService.Navigate(new Uri("/Views/Alumne/ReadAlumneList.xaml", UriKind.Relative));
            }
        }

        private void btnDeleteAlumne_Click(object sender, RoutedEventArgs e)
        {
            MessageBoxResult msg = MessageBox.Show("Estàs segur? Això eliminarà el registre", "Atenció!", MessageBoxButton.OKCancel);
            if (msg == MessageBoxResult.Cancel)
            {

            }
            else
            {
                Db_Helper.DeleteAlumne(Selected_AlumneId);
                NavigationService.Navigate(new Uri("/Views/Alumne/ReadAlumneList.xaml", UriKind.Relative));
            }
        }

        private void btnMenu_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/MainPage.xaml", UriKind.Relative));
        }

        private void btnSelActivitats_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/Views/Alumne/SelectActivitatAlumne.xaml?alumne=1", UriKind.Relative).ToString(), currentAlumne);
        }
    }
}