﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using DansApp.ViewModel;
using DansApp.Model;
using System.Text.RegularExpressions;

namespace DansApp.Views.Professor
{
    public partial class AddProfessor : PhoneApplicationPage
    {
        Model.Professor newprofessor = new Model.Professor();

        public AddProfessor()
        {
            InitializeComponent();
            this.Loaded += ReadActivitatsList_Loaded;
        }

        private bool IsValidEmail(string emailAddress)
        {
            return Regex.IsMatch(emailAddress, @"^([0-9a-zA-Z]([-\.\w]*[0-9a-zA-Z])*@([0-9a-zA-Z][-\w]*[0-9a-zA-Z]\.)+[a-zA-Z]{2,9})$");
        }

        private void btnMenu_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/MainPage.xaml", UriKind.Relative));
        }

        private void ReadActivitatsList_Loaded(object sender, RoutedEventArgs e)
        {
            if(newprofessor.Activitats == null)
            {
                newprofessor.Activitats = new List<Model.Activitat>();
            }
            if (NavigationContext.QueryString.ContainsKey("professor"))
            {
                string parameter = NavigationContext.QueryString["professor"];

                switch (parameter)
                {
                    case "1":
                        var myParameter = NavigationService.GetLastNavigationData();
                        if (myParameter != null)
                        {
                            newprofessor = (Model.Professor)myParameter;
                            if (newprofessor != null)
                            {
                                txtNom.Text = newprofessor.Nom;
                                txtCognoms.Text = newprofessor.Cognoms;
                                txtEmail.Text = newprofessor.Email;
                                txtTelefon.Text = newprofessor.Telefon.ToString();
                                if (newprofessor.Activitats != null)
                                {
                                    lbActivitats.ItemsSource = newprofessor.Activitats.OrderBy(i => i.Nom).ToList();
                                }
                            }
                        }
                        break;
                    default:
                        break;
                }
            }
        }

        private void btnAddProfessor_Click(object sender, RoutedEventArgs e)
        {
            long telefon;

            DatabaseHelperClass Db_Helper = new DatabaseHelperClass();
            if (string.IsNullOrEmpty(txtNom.Text))
            {
                MessageBox.Show("El nom és obligatori!");
            }
            else if (!string.IsNullOrEmpty(txtEmail.Text) && !this.IsValidEmail(txtEmail.Text))
            {
                MessageBox.Show("Siusplau introdueix un email amb format vàlid!");
            }
            else if (!string.IsNullOrEmpty(txtTelefon.Text) && !(long.TryParse(txtTelefon.Text, out telefon)))
            {
                MessageBox.Show("El telèfon no pot contenir caracters!");
            }
            else
            {
                long tempVal;
                long? tlf = Int64.TryParse(txtTelefon.Text, out tempVal) ? tempVal : (long?)null;
                newprofessor.Nom = txtNom.Text;
                newprofessor.Cognoms = txtCognoms.Text;
                newprofessor.Email = txtEmail.Text;
                newprofessor.Telefon = tlf;

                Db_Helper.Insert(newprofessor);
                NavigationService.Navigate(new Uri("/Views/Professor/ReadProfessorList.xaml", UriKind.Relative));
            }
        }

        private void btnSelActivitats_Click(object sender, RoutedEventArgs e)
        {
            long tempVal;
            long? tlf = Int64.TryParse(txtTelefon.Text, out tempVal) ? tempVal : (long?)null;
            newprofessor.Nom = txtNom.Text;
            newprofessor.Cognoms = txtCognoms.Text;
            newprofessor.Email = txtEmail.Text;
            newprofessor.Telefon = tlf;

            NavigationService.Navigate(new Uri("/Views/Professor/SelectActivitatProfessor.xaml?professor=1", UriKind.Relative).ToString(), newprofessor);
        }
    }
}