﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using DansApp.ViewModel;
using DansApp.Model;
using System.Text.RegularExpressions;

namespace DansApp.Views.Professor
{
    public partial class UpdateDeleteProfessor : PhoneApplicationPage
    {
        int Selected_ProfessorId = 0;

        DatabaseHelperClass Db_Helper = new DatabaseHelperClass();
        Model.Professor currentProfessor = new Model.Professor();

        public UpdateDeleteProfessor()
        {
            InitializeComponent();
        }

        private bool IsValidEmail(string emailAddress)
        {
            return Regex.IsMatch(emailAddress, @"^([0-9a-zA-Z]([-\.\w]*[0-9a-zA-Z])*@([0-9a-zA-Z][-\w]*[0-9a-zA-Z]\.)+[a-zA-Z]{2,9})$");
        }

        private void btnMenu_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/MainPage.xaml", UriKind.Relative));
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            if (NavigationContext.QueryString.ContainsKey("SelectedProfessorID"))
            {
                Selected_ProfessorId = int.Parse(NavigationContext.QueryString["SelectedProfessorID"]);
                currentProfessor = Db_Helper.ReadProfessor(Selected_ProfessorId);
                txtNom.Text = currentProfessor.Nom;
                txtCognoms.Text = currentProfessor.Cognoms;
                txtEmail.Text = currentProfessor.Email;
                txtTelefon.Text = currentProfessor.Telefon.ToString();
                lbActivitats.ItemsSource = currentProfessor.Activitats.OrderBy(i => i.Nom).ToList();
            }
            else
            {
                if (NavigationContext.QueryString.ContainsKey("professor"))
                {
                    string parameter = NavigationContext.QueryString["professor"];

                    switch (parameter)
                    {
                        case "1":
                            var myParameter = NavigationService.GetLastNavigationData();
                            if (myParameter != null)
                            {
                                currentProfessor = (Model.Professor)myParameter;

                                if(currentProfessor != null)
                                {
                                    txtNom.Text = currentProfessor.Nom;
                                    txtCognoms.Text = currentProfessor.Cognoms;
                                    txtEmail.Text = currentProfessor.Email;
                                    txtTelefon.Text = currentProfessor.Telefon.ToString();

                                    if(currentProfessor.Activitats != null)
                                    {
                                        lbActivitats.ItemsSource = currentProfessor.Activitats.OrderBy(i => i.Nom).ToList();
                                    }
                                }                               
                            }
                            break;
                        default:
                            break;
                    }
                }
            }
        }

        private void btnUpdateProfessor_Click(object sender, RoutedEventArgs e)
        {
            long telefon;
            if (string.IsNullOrEmpty(txtNom.Text))
            {
                MessageBox.Show("El nom és obligatori!");
            }
            else if (!string.IsNullOrEmpty(txtEmail.Text) && !this.IsValidEmail(txtEmail.Text))
            {
                MessageBox.Show("Siusplau introdueix un email amb format vàlid!");
            }
            else if (!string.IsNullOrEmpty(txtTelefon.Text) && !(long.TryParse(txtTelefon.Text, out telefon)))
            {
                MessageBox.Show("El telèfon no pot contenir caracters!");
            }
            else
            {
                currentProfessor.Nom = txtNom.Text;
                currentProfessor.Cognoms = txtCognoms.Text;
                currentProfessor.Email = txtEmail.Text;
                long tempVal;
                long? tlf = Int64.TryParse(txtTelefon.Text, out tempVal) ? tempVal : (long?)null;
                currentProfessor.Telefon = tlf;

                Db_Helper.UpdateProfessor(currentProfessor);
                NavigationService.Navigate(new Uri("/Views/Professor/ReadProfessorList.xaml", UriKind.Relative));
            }
        }

        private void btnDeleteProfessor_Click(object sender, RoutedEventArgs e)
        {
            MessageBoxResult msg = MessageBox.Show("Estàs segur? Això eliminarà el registre", "Atenció!", MessageBoxButton.OKCancel);
            if (msg == MessageBoxResult.Cancel)
            {

            }
            else
            {
                Db_Helper.DeleteProfessor(Selected_ProfessorId);
                NavigationService.Navigate(new Uri("/Views/Professor/ReadProfessorList.xaml", UriKind.Relative));
            }
        }

        private void btnSelActivitats_Click(object sender, RoutedEventArgs e)
        {
            NavigationService.Navigate(new Uri("/Views/Professor/SelectActivitatProfessor.xaml?professor=1", UriKind.Relative).ToString(), currentProfessor);
        }
    }
}